@@ -2,7 +2,7 @@
 context("Status")
 
 test_that("status() works when there is no library", {
-
+  skip_on_cran()
   renv_scope_options(renv.config.snapshot.preflight = FALSE)
 
   renv_tests_scope("breakfast")
@@ -49,4 +49,6 @@ test_that("status reports packages to be installed / changed", {
   status()
   snapshot()
 
+  expect_true(TRUE)
+
 })
